# Overview
`test-server` is a compiled binary for a Go web service based off the [gin tutorial](https://go.dev/doc/tutorial/web-service-gin).

Start its execution before trying to run `test_performance.py`

*I'm aware this performance test does not replicate real-world conditions.*
